package org.jeecg;

import cn.com.ctop.check.component.execute.GroovyScriptExecutor;
import cn.com.ctop.check.entity.CtopCheckTaskList;
import cn.com.ctop.check.service.ICtopCheckTaskListService;
import cn.com.ctop.common.module.entity.BindAccountLogin;
import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.entity.UserAllocation;
import cn.com.ctop.common.module.message.handle.impl.EmailSendMsgHandle;
import cn.com.ctop.common.module.service.*;
import cn.com.ctop.common.module.utils.CtopAdConstant;
import cn.com.ctop.kuaishou.modules.batch.service.IKuaiShouHistoryReportTaskService;
import cn.com.ctop.kuaishou.modules.graphql.service.IKuaishouWebInterfaceService;
import cn.com.ctop.kuaishou.modules.report.service.IKuaishouReportDailyAgentService;
import cn.com.ctop.toutiao.modules.material.service.IByteDanceAdvertiserDataService;
import cn.com.ctop.toutiao.modules.report.service.IByteDanceVideoReportDailyService;
import cn.com.ctop.toutiao.modules.report.service.IBytedanceReportService;
import cn.com.ctop.toutiao.modules.report.service.IReportService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.xxl.job.core.log.XxlJobLogger;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.DateUtils;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

@RunWith(SpringRunner.class)
@SpringBootTest(webEnvironment = SpringBootTest.WebEnvironment.RANDOM_PORT)
@ActiveProfiles("wps")
@Slf4j
public class SampleTest {
    @Autowired
    private ICtopOauthTokenService oauthTokenService;
    @Autowired
    private IKuaishouReportDailyAgentService kuaishouReportDailyAgentService;
    @Autowired
    private IReportService reportService;
    @Autowired
    private IByteDanceAdvertiserDataService advertiserDataService;
    @Autowired
    private IKuaiShouHistoryReportTaskService kuaiShouHistoryReportTaskService;

    @Autowired
    private ICtopOauthTokenService tokenService;

    @Test
    public void loadBytedanceCreativeData() {
        QueryWrapper<CtopOauthToken> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("media_id", 2);
        List<CtopOauthToken> list = oauthTokenService.list(queryWrapper);
        for (CtopOauthToken token : list) {
            kuaiShouHistoryReportTaskService.createTask(token.getAccountId(), token.getAccessToken(), "2020-09-20", "2020-09-20", "daily");

        }
    }

    @Test
    public void getTaskList() {
        kuaiShouHistoryReportTaskService.getTaskList();
    }


    @Autowired
    private IBindAccountLoginService bindAccountLoginService;
    @Autowired
    private IKuaishouWebInterfaceService kuaishouWebInterfaceService;

    @Test
    public void loadKuaishouCookie() {
        List<BindAccountLogin> list = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (list != null && !list.isEmpty()) {
            int i = 0;
            for (BindAccountLogin login : list) {
                if (null == login.getCookie() || "".equals(login.getCookie().trim())) {
                    if (i > 5) {
                        break;
                    }
                    kuaishouWebInterfaceService.getkuaishouWebLoginCookie(login);
                    i++;
                }
            }
        }
    }

    static ExecutorService executorService = null;
    //线程计数器/bytedance/bytedanceMaterialReport
    static CountDownLatch countDownLatch = null;

    @Test
    public void deleteKuaishouComment() {
        Long start = System.currentTimeMillis();
        List<BindAccountLogin> loginList = bindAccountLoginService.getListByParams(CtopAdConstant.PLATFORM_TYPE_KUAISHOU_PY, 1);
        if (loginList != null && !loginList.isEmpty()) {
            executorService = Executors.newFixedThreadPool(5);
            countDownLatch = new CountDownLatch(loginList.size());
            loginList.forEach(login -> executorService.submit(() -> {
                try {
                    kuaishouWebInterfaceService.deleteAllComment(new HashMap<>(), login);
                } catch (Exception e) {
                    log.error(e.getMessage(), e);
                } finally {
                    countDownLatch.countDown();
                }
            }));
            try {
                countDownLatch.await();
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
            Long end = System.currentTimeMillis();
            log.info("快手删评论所用时长：{}毫秒", end - start);
        }
    }

    @Autowired
    private IUserAllocationService allocationService;

    @Test
    public void testLoadBytedanceData() {
        List<UserAllocation> allocations = allocationService.getByParams(435L, null, 0);
        for (UserAllocation allocation : allocations) {
            for (int i = 2; i < 10; i++) {
                CtopOauthToken token = oauthTokenService.getTokenByAccountId(allocation.getAccountId());
                Date getDate = DateUtils.addDay(new Date(), -i);
                reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }
        }
    }

    @Test
    public void loadKuaishouAgentData() {
        kuaishouReportDailyAgentService.loginAgent();
//        for (int i = 0; i < 20; i++) {
//            String currentDate = DateUtils.formatDate(DateUtils.addDay(new Date(), -i));
//            kuaishouReportDailyAgentService.getReport(currentDate, DateUtils.getNowDate("yyyy-MM-dd"));
//        }
//
        try {
            for (int i = 1; i < 30; i++) {
                kuaishouReportDailyAgentService.getAccount(i);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    @Autowired
    private GroovyScriptExecutor groovyScriptExecutor;

    @Autowired
    private ICtopCheckTaskListService checkTaskListService;

    @Test
    public void checkDataStateJobTest() {
        //查询需要检查的任务列表
        List<CtopCheckTaskList> ctopCheckTaskList = checkTaskListService.queryExecuteList("checkDataStateJob");
        if (ctopCheckTaskList != null) {
            ctopCheckTaskList.forEach(it -> groovyScriptExecutor.execute(it));
        }
    }

    @Test
    public void loadAccountData() {
//        List<UserAllocation> allocations = allocationService.getByParams(776L,null,0);
//        for (UserAllocation allocation:allocations) {
            CtopOauthToken token = tokenService.getTokenByAccountId(93238965516L);
            for(int i=92;i<100;i++){
                Date getDate = DateUtils.addDay(new Date(),-i);
                reportService.getAdvertiserReport(token, getDate, getDate, CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }
//        }
    }

    @Autowired
    IUReportExportService uReportExportService;
    @Autowired
    EmailSendMsgHandle emailSendMsgHandle;
    @Autowired
    IUReportService uReportService;

    @Test
    public void loadBytedanceData(){
        String strings = "1672894840372238_1674183267750990_1673076203257870_1650079154438157_1670286873337870_1648709018451972_1661556811389966_1676540488471559";
        String[] tokens = strings.split("_");
        for (int i=0;i<tokens.length;i++) {
            Long accountId = Long.parseLong(tokens[i]);
            CtopOauthToken token = tokenService.getTokenByAccountId(accountId);
            for(int j=10;j<110;j++){
                Date getDate = DateUtils.addDay(new Date(), -j);
                reportService.getAdvertiserReport(token, getDate, getDate,CtopAdConstant.BYTEDANCE_REPORT_TYPE_DAILY);
            }

        }
    }

    @Test
    public void loaddata(){
        for(int i=0;i<30;i++){
            Date getDate = DateUtils.addDay(new Date(), -i);
            String date = DateUtils.formatDate(getDate);
            videoReportDailyService.videoInfoList(date, date);
        }
    }

    @Autowired
    private IBytedanceReportService bytedanceReportService;

    @Autowired
    private IByteDanceVideoReportDailyService videoReportDailyService;
    @Test
    public void loadMatData(){
        List<UserAllocation> allocations = allocationService.getByParams(320L,null,0);
        countDownLatch = new CountDownLatch(allocations.size());
        executorService = Executors.newFixedThreadPool(2);
        allocations.forEach(allocation -> {
            executorService.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        CtopOauthToken token = tokenService.getTokenByAccountId(allocation.getAccountId());
                        //获取全量视频素材数据
                        advertiserDataService.getMaterialList(token);
                    } catch (Exception e) {
                        e.printStackTrace();
                    } finally {
                        countDownLatch.countDown();
                    }
                }
            });
        });
        try {
            countDownLatch.await();
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        XxlJobLogger.log("物料数据同步完成");
    }
}
